# Copyright (C) 2007, 2009 by Intevation GmbH
# Authors:
# Bernhard Herzog <bh@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING coming with the software for details.

"""Access to resources bundled with InteProxy"""

import sys
import os
import gettext as py_gettext

def in_py2exe():
    """Returns whether the program is running as a py2exe executable"""
    return getattr(sys, "frozen", None) == "windows_exe"

# determine share_dir, the name of the directroy containing the resource
# files like images and translations.  When run directly from the source
# tree, the share_dir can be determined from the directory containing
# this python module.  When run from a frozen windows executable created
# with py2exe that doesn't work, but we can start from the directory
# containing the executable.
if in_py2exe():
    _base_dir = os.path.dirname(sys.executable)
else:
    _base_dir =  os.path.join(os.path.dirname(__file__), os.pardir)
share_dir = os.path.join(_base_dir, "share")

def gettext(message):
    """Translates the message according to the user's locale.

    If a translation can be found, the return value is a unicode object
    otherwise the message is returned unchanged.
    """
    modir = os.path.join(share_dir, "locale")
    t = py_gettext.translation("inteproxy", modir, fallback=True)

    return t.ugettext(message)


def image_filename(basename):
    """Returns the filename of image files bundled with InteProxy.

    The function assumes that all image files are located in the
    inteproxy package directory.  The parameter basename should be the
    basename of the image file in that directory.
    """
    return os.path.join(share_dir, "images", basename)


def default_config_file():
    """Returns the name of the default configuration file"""
    return os.path.join(_base_dir, "inteproxy.cfg")

def default_credentials_file():
    """Returns the name of the default credentials file"""
    return os.path.join(_base_dir, "credentials.cfg")
