# Copyright (C) 2007, 2008 by Intevation GmbH
# Authors:
# Bernhard Herzog <bh@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING coming with the software for details.

"""Tests for inteproxy.httpserver and serversupport

The tests of inteproxy.httpserver are done indirectly via the server
implemented in serversupport so that the tests server more or less as
tests for both modules.
"""

import sys
import os
import httplib
import unittest

import serversupport

import inteproxy.httpserver as httpserver


class SimpleHTTPServerTests(unittest.TestCase):

    server_contents = [
        ("/wms", [("Content-Type", "text/plain")], "wms data"),
        ]

    def setUp(self):
        self.old_stderr = sys.stderr
        sys.stderr = open(os.path.devnull, "w")
        server = serversupport.HTTPServer(self.server_contents)
        self.server = httpserver.ServerThread(server)
        self.server.start(daemon=True)

    def tearDown(self):
        try:
            self.server.stop()
        finally:
            sys.stderr = self.old_stderr

    def test_get_200(self):
        http = httplib.HTTPConnection("localhost", self.server.server_port)
        http.request("GET", "/wms")
        response = http.getresponse()
        self.assertEquals(response.status, 200)
        self.assertEquals(response.read(), "wms data")

    def test_get_404(self):
        http = httplib.HTTPConnection("localhost", self.server.server_port)
        http.request("GET", "/something/that/doesnt/exist")
        response = http.getresponse()
        self.assertEquals(response.status, 404)
